@@ -5,9 +5,6 @@ import errno
 from struct import calcsize
 
 
-DEFAULT_ENV = 0x1
-GEVENT_ENV = 0x2
-
 LENGTH_FORMAT = '!i'
 
 LENGTH_SIZE = calcsize(LENGTH_FORMAT)
